utils::globalVariables(c("%>%",
                         "..p.format..",
                         "xend",
                         "x",
                         "y",
                         "AlignSubspace",
                         "CaseMatch",
                         "CreateSeuratObject",
                         "FindVariableGenes",
                         "Freq",
                         "Mito.UMIs",
                         "MyLev",
                         "NormalizeData",
                         "PCs",
                         "RunCCA",
                         "S.phase.probability",
                         "SDs",
                         "ScaleData",
                         "SetAllIdent",
                         "StashIdent",
                         "UMIs",
                         "Var1",
                         "baseMean",
                         "cdr3",
                         "cell",
                         "cells",
                         "chain",
                         "clusters",
                         "color",
                         "conditions",
                         "distance",
                         "event_data",
                         "g2m.phase",
                         "g2m.phase.probability",
                         "gene",
                         "gene.filter",
                         "genes",
                         "immgen.rna",
                         "immgen.uli.rna",
                         "demo.obj",
                         "my.vdj",
                         "lfc",
                         "log2FoldChange",
                         "magic",
                         "mito.percent",
                         "mouse.cell.atlas",
                         "my.vdj.chain",
                         "nGenes",
                         "numberOfCells",
                         "padj",
                         "phate",
                         "plotlyOutput",
                         "productive",
                         "pval",
                         "pvalue",
                         "raw_clonotype_id",
                         "renderPlotly",
                         "s.phase",
                         "scale_size",
                         "unit",
                         "cell.barcodes",
                         "Expression",
                         "Conditions",
                         "col.legend.bin",
                         "Clusters",
                         "Rphenograph",
                         "membership",
                         "SerialParam",
                         "SingleCellExperiment",
                         "computeSumFactors",
                         "normalize",
                         "out",
                         "DefaultAssay<-",
                         "IntegrateData",
                         "FindIntegrationAnchors",
                         "FindVariableFeatures",
                         "DiffusionMap",
                         "SCTransform",
                         "Norm.Freq",
                         "SelectIntegrationFeatures",
                         "PrepSCTIntegration",
                         "Phase",
                         "percentage",
                         "Immgen.microarray.GSE37448.189",
                         "Immgen.microarray.GSE15907.653",
                         "Immgen.GSE124829.190",
                         "Immgen.GSE122597.83",
                         "Immgen.GSE122108.412",
                         "Immgen.GSE109125.205",
                         "yend",
                         "gg_color_hue",
                         "hcl",
                         "V",
                         "CellIds",
                         "V<-",
                         "annotate"))
